Discover Packages
github.com/leakingtapan/sonoff
pkg
types
package
Version:
v0.0.0-...-d6813a9
Opens a new window with list of versions in this module.
Published: Oct 5, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Device struct {
DeviceId string `json:"deviceid"`
ApiKey string `json:"apikey"`
Version int `json:"version"`
RomVersion string `json:"romVersion"`
Model string `json:"model"`
State string `json:"state"`
}
type Message struct {
Action Action `json:"action"`
DeviceId string `json:"deviceid"`
UserAgent string `json:"userAgent"`
ApiKey string `json:"apikey"`
Version int `json:"version"`
RomVersion string `json:"romVersion"`
Model string `json:"model"`
Ts int64 `json:"ts"`
}
type QueryMessage struct {
Message
Params []string `json:"params"`
}
type UpdateParams struct {
Switch string `json:"switch"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.